# geepers

[![Actions Status][actions-badge]][actions-link]
[![PyPI version][pypi-version]][pypi-link]
[![Documentation Status][rtd-badge]][rtd-link]

[![Conda-Forge][conda-badge]][conda-link]
[![GitHub Discussion][github-discussions-badge]][github-discussions-link]


<!-- prettier-ignore-start -->
[actions-badge]:            https://github.com/isce-framework/geepers/workflows/CI/badge.svg
[actions-link]:             https://github.com/isce-framework/geepers/actions
[conda-badge]:              https://img.shields.io/conda/vn/conda-forge/geepers
[conda-link]:               https://github.com/conda-forge/geepers-feedstock
[github-discussions-badge]: https://img.shields.io/static/v1?label=Discussions&message=Ask&color=blue&logo=github
[github-discussions-link]:  https://github.com/isce-framework/geepers/discussions
[pypi-link]:                https://pypi.org/project/geepers/
[pypi-platforms]:           https://img.shields.io/pypi/pyversions/geepers
[pypi-version]:             https://img.shields.io/pypi/v/geepers
[rtd-badge]:                https://readthedocs.org/projects/geepers/badge/?version=latest
[rtd-link]:                 https://geepers.readthedocs.io/en/latest/?badge=latest

<!-- prettier-ignore-end -->
